# HSCOMBINE - Combine multispec files, removing cosmic rays in the process
# February 24, 2005
# By Doug Mink, SAO Telescope Data Center

procedure hscombine (images, output)

string	images=""	{prompt="Images to combine"}
file	output=""	{prompt="Output image"}
string	apertures = "1-300"	{prompt="Range of apertures to combine"}
string	combine = "average"	{prompt="Combine images (average|median|sum)"}
string	reject = "ccdclip"	{prompt="Reject method (none|minmax|ccdclip|crreject|sigclip|avsigclip|pclip)"}
bool	saveold = yes	{prompt="Save uncombined files in Uncombined/ (y or n)"}
bool	deltemp = no	{prompt="Delete intermediate image files (y or n)"}
bool	verbose = yes	{prompt="Print process progress (y or n)"}
bool	debug = no	{prompt="Print information for debugging (y or n)"}

begin

string	imagelist
file	imageout, imin
bool	vb
int	nim

	vb = verbose
	db = debug
	imagelist = images
	imageout = output

#  Make temporary list of input files and get name of first file
        templist = mktemp ("scomblist")
        files (imagelist, >templist)
	list = templist
	fscan (list, imin)
	imgetp (imin, "APID1", verbose=db)
	nim = 1
	while (fscan (list,imin) != EOF) {
	    nim = nim + 1
	    }

	if (vb) {
	    print ("HCOMBINE1: ", nim, " images combined into ",imageout)
	    }

# Initialize scombine
	scombine.noutput = ""
	scombine.logfile = "STDOUT"
	scombine.apertures = apertures
	scombine.group = "apertures"
	scombine.combine = combine
	scombine.reject = reject
	scombine.first = yes
	scombine.w1 = INDEF
	scombine.w2 = INDEF
	scombine.dw = INDEF
	scombine.nw = INDEF
	scombine.log = no
	scombine.scale = "mean"
	scombine.zero = "none"
	scombine.weight = "none"
	scombine.sample = ""
	scombine.lthreshold = INDEF
	scombine.hthreshold = INDEF
	scombine.nlow = 1
	scombine.nhigh = 1
	scombine.nkeep = 1
	if (nim < 5) {
	    scombine.mclip = no
	    }
	else {
	    scombine.mclip = yes
	    }
	scombine.lsigma = 3.
	scombine.hsigma = 3.
	scombine.rdnoise = "2.7"
	scombine.gain = "1."
	scombine.snoise = "0."
	scombine.sigscale = 0.1
	scombine.pclip = -0.5
	scombine.grow = 0
	scombine.blank = 0.
	scombine.mode = "ql"

# Combine multispec images
	scombine (imagelist, imageout)

# Copy APID1 from first input image to output image
	hedit (imageout, "APID1", imgetp.value, add+, verify-)

# Add history line including time
        gettime ()
        history = gettime.date // " " // gettime.time // " " // nim // " images scombined"
        hedit (imageout, "HCOMBINE", history, add+, verify-)

# Make directory to save input files, if needed
	if (saveold) {
	    if (!access ("Notcombined/")) {
		mkdir ("Notcombined")
		}
	    }

# Add list of files copied
	i = 0
	list = templist
	while (fscan (list,imin) != EOF) {
	    i = i + 1
	    keyword = "HCOMB" // i
            hedit (imageout, keyword, imin, add+, verify-)
	    if (saveold) {
		newfile = "Notcombined/" // imin
		if (access (newfile) {
		    imdelete (newfile)
		    }
		movefiles (imin, "Notcombined")
		}
	    }
	if (deltemp) {
	    delete (templist)
	    }
end

# Jan 10 2005	New program to remove cosmic rays from spectra
# Feb 24 2005	Use Susan's defaults; add file transfer to subdirectory 
# Feb 24 2005	Add history, filename saving and APID1 transfer
