# HFLAT -- Divide hectospec image by pixel normalization file from apflatten
#          saving original file in Unflat/
# By Doug Mink, SAO Telescope Data Center
# October 18, 2004

procedure hflat (images)

string	images = ""	{prompt="Input multispec image(s) to correct"}
string	normfile=""	{prompt="Pixel to pixel normalization file from apflatten"}
bool deltemp = no	{prompt="Delete temporary files (y or n)"}
bool saveold = yes	{prompt="Save original file to Nonorm/ (y or n)"}
bool verbose = yes	{prompt="Log progress (y or n)"}

begin
	bool vb
	file imin, imout, imroot, imnorm, newfile, templist
	int lroot
	string history, ims, tchar

	ims = images
	vb = verbose
	imnorm = normfile


#  Make temporary list of input files
	tchar = substr (ims,1,1)
	if (tchar == '@') {
	    templist = substr (ims,2,100)
	    deltemp = no
	    }
	else {
            templist = mktemp ("flatlist")
            files (ims, >templist)
	    }
        list = templist
        while (fscan (list,imin) != EOF) {

# Do not flatten spectra twice
	    imgetp.default = "0"
	    imgetp (imin, "HFLAT")
	    if (imgetp.value != "0") {
		if (vb) {
		    print ("HFLAT: ", imin, " has been processed")
		    print ("HFLAT = ", imgetp.value)
		    }
		next
		}
	    else {
		imgetp (imin, "PIXNORM")
		if (imgetp.value != "0") {
		    if (vb) {
			print ("HFLAT: ", imin, " has been processed")
			}
		    next
		    }
		}

# Remove extension from input file, if one is present, and make output file name
	    smatch (imin, ".fits")
	    if (smatch.found) {
		lroot = smatch.start - 1
		imout = substr (imin, 1, lroot) // ".flattened.fits"
		}
	    else {
		imout = imin // ".flattened.fits"
		imin = imin // ".fits"
		}

# Add FITS extension to normalization file if it is missing
	    smatch (imnorm, ".fits")
	    if (!smatch.found) {
		imnorm = imnorm // ".fits"
		}
	    if (vb) {
		print ("HFLAT: ", imin," -> ",imout," using ", imnorm)
		}

# Divide out normalization spectra
	    imarith (imin, "/", imnorm, imout)

# Move original file to Unflat directory
	    if (saveold) {
		if (!access ("Unflat/")) {
		    mkdir ("Unflat")
		    }
		newfile = "Unflat/" // imin
		if (access (newfile)) {
		    imdelete (newfile)
		    }
		movefiles (imin, "Unflat")
		if (vb) {
		    print ("HFLAT: Original ", imin, " => Unflat/")
		    }
		}
	    else {
		delete (imin)
		}

# Rename result file to original file name
	    rename (imout, imin)

# Add history line including time
	    gettime ()
	    history = gettime.date // " " // gettime.time // " pixels normalized by " // imnorm
            hedit (imin, "HFLAT", history, add+, verify-)
	    }
	if (deltemp) {
	    delete (templist)
	    }

end
# Jun 16 2004	Change name form HNORM2 to HFLAT
# Jun 16 2004	Move original file to Unflat/, not Nonorm/
# Sep  2 2004	Allow multiple images to be processed at once
# Sep  2 2004	Test history keyword to avoid rerunning program on file
# Oct 18 2004	If image has already been flattened, print value of HFLAT
# Mar 29 2005   WFW - Fix bug in creating imout name
