#
# Fit and remove 'red leak' continuum from a spectrum
#
# 2005-03-02 Bill Wyatt
#
# Requires 'untools' for pmkdir ("mkdir -p") function
#

procedure hredleak(input)

string input    = ""	{prompt="Input file(s)"}
string outdir   = "./"	{prompt="Output directory"}
string suffix   = "_r"	{prompt="Suffix for output files"}
real   lambda   = 8520.0	{prompt="Minimum wavelength for red leak"}
int    band     = 1	{prompt="First band of image to correct"}
int    endband  = 0	{prompt="Last band of image to correct"}
bool   dounused = no	{prompt="Correct unused fibers (y or n)"}
bool   verbose  = no	{prompt="Print extra information about process"}

begin

  string infile
  string outfile
  string intmp
  string basedir
  int    i

  intmp = osfn("tmp$") // mktemp("rdlk_") // ".lis"

  infile = input
  files (infile, > intmp)

  list = intmp
  while(fscan(list, infile) != EOF) {

    pmkdir(outdir, >& "dev$null")

    outfile=infile
    basedir=""
 
 # get the bare filename from the input file
    while(yes) {
      i = stridx("/", outfile)
      if(i == 0) break
      basedir = basedir // substr(outfile, 1, i)
      outfile = substr(outfile, i+1, strlen(outfile))
    }

 # add the suffix and output dir to the output filename
    i=strlen(infile)
    
    if(i > 3 && substr(infile,i-2,i) == ".ms")
       outfile = outdir // substr(outfile,1,strlen(outfile)-3) // 
                                                   suffix // ".ms"
    else if(i > 8 && substr(infile,i-7,i) == ".ms.fits")
       outfile = outdir // substr(outfile,1,strlen(outfile)-8) // 
                                                   suffix // ".ms.fits"
    else if(i > 7 && substr(infile,i-6,i) == ".ms.fit")
       outfile = outdir // substr(outfile,1,strlen(outfile)-7) // 
                                                    suffix // ".ms.fit"
    else if(i > 7 && substr(infile,i-6,i) == ".ms.fts")
       outfile = outdir // substr(outfile,1,strlen(outfile)-7) // 
                                                    suffix // ".ms.fts"
    else if(i > 7 && substr(infile,i-6,i) == ".ms.imh")
       outfile = outdir // substr(outfile,1,strlen(outfile)-7) // 
                                                    suffix // ".ms.imh"
    else if(substr(infile,i-4,i) == ".fits") 
       outfile = outdir // substr(outfile,1,strlen(outfile)-5) //
                                                    suffix // ".fits"
    else if(substr(infile,i-3,i) == ".imh") 
       outfile = outdir // substr(outfile,1,strlen(outfile)-4) // 
                                                    suffix // ".imh"
    else if(substr(infile,i-3,i) == ".fit") 
       outfile = outdir // substr(outfile,1,strlen(outfile)-4) // suffix //".fit"
    else if(substr(infile,i-3,i) == ".fts") 
       outfile = outdir // substr(outfile,1,strlen(outfile)-4) // suffix //".fts"
    else
       outfile = outdir // outfile // suffix

   if(verbose) 
     printf ("doredleak(%.1f): %s -> %s\n", 
        lambda, infile, outdir // "*" // suffix)
   redleakcorr(infile, outfile, lambda=lambda, band=band, endband=endband,
               dounused=dounused, verbose=verbose)

  }

  delete(intmp, ver-, >& "dev$null")

end
